@@ -1,28 +1,61 @@
 #!/usr/bin/env dnsjit
 local pcap = arg[2]
 local compression = arg[3]
+local mmap = arg[4]
 
 if pcap == nil then
-    print("usage: "..arg[1].." <pcap> [compression]")
+    print("usage: "..arg[1].." <pcap | '-' for stdin> [compression] [mmap]")
     return
 end
 
 local object = require("dnsjit.core.objects")
 local input = require("dnsjit.input.pcap").new()
 local zinput = require("dnsjit.input.zpcap").new()
+if mmap then
+    zinput = require("dnsjit.input.zmmpcap").new()
+end
 local layer = require("dnsjit.filter.layer").new()
 local dns = require("dnsjit.core.object.dns").new()
 
 if string.lower(string.sub(pcap, -4)) == ".zst" or compression == "zstd" then
     zinput:zstd()
-    zinput:open(pcap)
+    if pcap == "-" then
+        zinput:openfp(io.stdin)
+    else
+        zinput:open(pcap)
+    end
     layer:producer(zinput)
 elseif string.lower(string.sub(pcap, -4)) == ".lz4" or compression == "lz4" then
     zinput:lz4()
-    zinput:open(pcap)
+    if pcap == "-" then
+        zinput:openfp(io.stdin)
+    else
+        zinput:open(pcap)
+    end
+    layer:producer(zinput)
+elseif string.lower(string.sub(pcap, -3)) == ".xz" or compression == "xz" then
+    zinput:lzma()
+    if pcap == "-" then
+        zinput:openfp(io.stdin)
+    else
+        zinput:open(pcap)
+    end
+    layer:producer(zinput)
+elseif string.lower(string.sub(pcap, -3)) == ".gz" or compression == "gz" then
+    zinput:gzip()
+    if pcap == "-" then
+        zinput:openfp(io.stdin)
+    else
+        zinput:open(pcap)
+    end
     layer:producer(zinput)
 else
-    input:open_offline(pcap)
+    if mmap then
+        input = require("dnsjit.input.mmpcap").new()
+        input:open(pcap)
+    else
+        input:open_offline(pcap)
+    end
     layer:producer(input)
 end
 local producer, ctx = layer:produce()
