@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2025 OARC, Inc.
+ * Copyright (c) 2018-2026 OARC, Inc.
  * All rights reserved.
  *
  * This file is part of dnsjit.
@@ -24,6 +24,10 @@
 #ifndef __dnsjit_core_channel_h
 #define __dnsjit_core_channel_h
 
+#ifdef __clang_analyzer__
+#define CK_USE_CC_BUILTINS 0
+#endif
+
 #if defined(__GNUC__) || defined(__SUNPRO_C)
 #include "gcc/ck_cc.h"
 #ifdef CK_CC_RESTRICT
