@@ -1,4 +1,4 @@
--- Copyright (c) 2018-2025 OARC, Inc.
+-- Copyright (c) 2018-2026 OARC, Inc.
 -- All rights reserved.
 --
 -- This file is part of dnsjit.
@@ -737,17 +737,19 @@ function Dns:print(num_labels)
 end
 
 -- Return the textual name for a class.
+-- Unknown classes will be returned as "CLASS<NUM>", as described in RFC 3597.
 function Dns.class_tostring(class)
     if Dns.CLASS_STR[class] == nil then
-        return "UNKNOWN("..class..")"
+        return "CLASS"..class
     end
     return Dns.CLASS_STR[class]
 end
 
 -- Return the textual name for a type.
+-- Unknown types will be returned as "TYPE<NUM>", as described in RFC 3597.
 function Dns.type_tostring(type)
     if Dns.TYPE_STR[type] == nil then
-        return "UNKNOWN("..type..")"
+        return "TYPE"..type
     end
     return Dns.TYPE_STR[type]
 end
