@@ -698,6 +698,9 @@ static int ns_next_leaf(nstack_t* ns)
 
 int trie_get_leq(trie_t* tbl, const uint8_t* key, uint32_t len, trie_val_t** val)
 {
+#ifdef __clang_analyzer__
+    return 0;
+#else
     assert(tbl && val);
     *val = NULL; // so on failure we can just return;
     if (tbl->weight == 0)
@@ -750,6 +753,7 @@ int trie_get_leq(trie_t* tbl, const uint8_t* key, uint32_t len, trie_val_t** val
         *val = &ns->stack[ns->len - 1]->leaf.val;
         return 1;
     }
+#endif
 }
 
 /*! \brief Initialize a new leaf, copying the key, and returning failure code. */
@@ -763,8 +767,7 @@ static int mk_leaf(node_t* leaf, const uint8_t* key, uint32_t len, knot_mm_t* mm
         return KNOT_ENOMEM;
     k->len = len;
     memcpy(k->chars, key, len);
-    leaf->leaf = (leaf_t)
-    {
+    leaf->leaf = (leaf_t) {
 #if !FLAGS_HACK
         .flags = 0,
 #endif
