@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021, OARC, Inc.
+ * Copyright (c) 2018-2026 OARC, Inc.
  * All rights reserved.
  *
  * This file is part of dnsjit.
@@ -212,7 +212,7 @@ int output_dnscli_connect(output_dnscli_t* self, const char* host, const char* p
         }
         if (self->timeout.sec > 0 || self->timeout.nsec > 0) {
             self->poll.fd      = self->fd;
-            self->poll_timeout = (self->timeout.sec * 1e3) + (self->timeout.nsec / 1e6); //NOSONAR
+            self->poll_timeout = (self->timeout.sec * 1e3) + (self->timeout.nsec / 1e6); // NOSONAR
             if (!self->poll_timeout) {
                 self->poll_timeout = 1;
             }
@@ -248,7 +248,7 @@ int output_dnscli_connect(output_dnscli_t* self, const char* host, const char* p
     return 0;
 }
 
-inline ssize_t _send_udp(output_dnscli_t* self, const uint8_t* payload, size_t len, size_t sent)
+static inline ssize_t _send_udp(output_dnscli_t* self, const uint8_t* payload, size_t len, size_t sent)
 {
     ssize_t n;
 
@@ -331,7 +331,7 @@ static void _receive_udp(output_dnscli_t* self, const core_object_t* obj)
     self->errs++;
 }
 
-inline ssize_t _send_tcp(output_dnscli_t* self, const uint8_t* payload, size_t len, size_t sent)
+static inline ssize_t _send_tcp(output_dnscli_t* self, const uint8_t* payload, size_t len, size_t sent)
 {
     ssize_t n;
 
@@ -432,7 +432,7 @@ static void _receive_tcp(output_dnscli_t* self, const core_object_t* obj)
     self->errs++;
 }
 
-inline ssize_t _send_tls(output_dnscli_t* self, const uint8_t* payload, size_t len, size_t sent)
+static inline ssize_t _send_tls(output_dnscli_t* self, const uint8_t* payload, size_t len, size_t sent)
 {
     ssize_t n;
 
